@@ -684,6 +684,10 @@ var app = window.Yancy = new Vue({
 
         fillUrl: function ( tmpl, data ) {
             return tmpl.replace( /\{([^}]+)\}/g, function ( match, field ) {
+                if ( !data[field].replace ) {
+                    // This must not be a string, so we can't escape it...
+                    return data[field];
+                }
                 // This works the same as Mojo::Util xml_escape
                 return data[field].replace( /[&<>"']/g, function ( match ) {
                     switch ( match ) {
